==> gcl-1.0.tgz: gcl-1.0/cmpnew/cmpenv.h <==

static L2();
static L4();
static L7();
static L8();
static L18();
static L22();
static L24();
static object LI1();
#define VMB1
#define VMS1
#define VMV1
#define VMR1(VMT1) return(VMT1);
#define VC2
static object LI3();
#define VMB3 object  V8;
#define VMS3
#define VMV3
#define VMR3(VMT3) return(VMT3);
#define VC4
static object LI5();
#define VMB5 register object *base=vs_top; object  V24 ,V22 ,V20 ,V15 ,V14;
#define VMS5  register object *sup=vs_top+2;vs_top=sup;
#define VMV5 vs_reserve(2);
#define VMR5(VMT5) vs_top=base ; return(VMT5);
static object LI6();
#define VMB6 object  V32 ,V31;
#define VMS6
#define VMV6
#define VMR6(VMT6) return(VMT6);
#define VC7
#define VC8
static object LI9();
#define VMB9 register object *base=vs_top; object  V45 ,V44;
#define VMS9 vs_top += 1;
#define VMV9 vs_reserve(1);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI10();
#define VMB10
#define VMS10
#define VMV10
#define VMR10(VMT10) return(VMT10);
static object LI11();
#define VMB11 object  V69;
#define VMS11
#define VMV11
#define VMR11(VMT11) return(VMT11);
static object LI12();
#define VMB12 object  V82 ,V81 ,V80;
#define VMS12
#define VMV12
#define VMR12(VMT12) return(VMT12);
static object LI13();
#define VMB13
#define VMS13
#define VMV13
#define VMR13(VMT13) return(VMT13);
static object LI14();
#define VMB14 register object *base=vs_top;
#define VMS14 vs_top += 3;
#define VMV14 vs_reserve(3);
#define VMR14(VMT14) vs_top=base ; return(VMT14);
static object LI15();
#define VMB15
#define VMS15
#define VMV15
#define VMR15(VMT15) return(VMT15);
static object LI16();
#define VMB16
#define VMS16
#define VMV16
#define VMR16(VMT16) return(VMT16);
static object LI17();
#define VMB17
#define VMS17
#define VMV17
#define VMR17(VMT17) return(VMT17);
#define VC18
static object LI19();
#define VMB19 object  V117;
#define VMS19
#define VMV19
#define VMR19(VMT19) return(VMT19);
static object LI20();
#define VMB20 register object *base=vs_top; object  V143 ,V142;
#define VMS20  register object *sup=vs_top+5;vs_top=sup;
#define VMV20 vs_reserve(5);
#define VMR20(VMT20) vs_top=base ; return(VMT20);
static object LI21();
#define VMB21 register object *base=vs_top; object  V154;
#define VMS21 vs_top += 1;
#define VMV21 vs_reserve(1);
#define VMR21(VMT21) vs_top=base ; return(VMT21);
#define VC22 object  V183 ,V179 ,V176 ,V173;
static object LI23();
#define VMB23 register object *base=vs_top; object  V207 ,V204 ,V199 ,V198;
#define VMS23  register object *sup=vs_top+11;vs_top=sup;
#define VMV23 vs_reserve(11);
#define VMR23(VMT23) vs_top=base ; return(VMT23);
#define VC24
static object LI25();
#define VMB25 register object *base=vs_top;
#define VMS25 vs_top += 1;
#define VMV25 vs_reserve(1);
#define VMR25(VMT25) vs_top=base ; return(VMT25);
static object LI26();
#define VMB26 register object *base=vs_top; object  V301 ,V279 ,V278 ,V276 ,V275 ,V271 ,V270 ,V269 ,V268 ,V249 ,V245 ,V244;
#define VMS26  register object *sup=vs_top+5;vs_top=sup;
#define VMV26 vs_reserve(5);
#define VMR26(VMT26) vs_top=base ; return(VMT26);
#define VM26 5
#define VM25 1
#define VM24 8
#define VM23 11
#define VM22 8
#define VM21 1
#define VM20 5
#define VM19 0
#define VM18 3
#define VM17 0
#define VM16 0
#define VM15 0
#define VM14 3
#define VM13 0
#define VM12 0
#define VM11 0
#define VM10 0
#define VM9 1
#define VM8 3
#define VM7 3
#define VM6 0
#define VM5 2
#define VM4 4
#define VM3 0
#define VM2 3
#define VM1 0
static char * VVi[188]={
#define Cdata VV[187]
(char *)(LI1),
(char *)(L2),
(char *)(LI3),
(char *)(L4),
(char *)(LI5),
(char *)(LI6),
(char *)(L7),
(char *)(L8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI14),
(char *)(LI15),
(char *)(LI16),
(char *)(LI17),
(char *)(L18),
(char *)(LI19),
(char *)(LI20),
(char *)(LI21),
(char *)(L22),
(char *)(LI23),
(char *)(L24),
(char *)(LI25),
(char *)(LI26)
};
#define VV ((object *)VVi)
static  LnkT186() ;
static  (*Lnk186)() = LnkT186;
static object  LnkTLI185() ;
static object  (*LnkLI185)() = LnkTLI185;
static object  LnkTLI184() ;
static object  (*LnkLI184)() = LnkTLI184;
static object  LnkTLI183() ;
static object  (*LnkLI183)() = LnkTLI183;
static object  LnkTLI182() ;
static object  (*LnkLI182)() = LnkTLI182;
static object  LnkTLI180() ;
static object  (*LnkLI180)() = LnkTLI180;
static object  LnkTLI179() ;
static object  (*LnkLI179)() = LnkTLI179;
static object  LnkTLI141() ;
static object  (*LnkLI141)() = LnkTLI141;
static object  LnkTLI135() ;
static object  (*LnkLI135)() = LnkTLI135;
static  LnkT130() ;
static  (*Lnk130)() = LnkT130;
static object  LnkTLI128() ;
static object  (*LnkLI128)() = LnkTLI128;
static object  LnkTLI127() ;
static object  (*LnkLI127)() = LnkTLI127;
static object  LnkTLI126() ;
static object  (*LnkLI126)() = LnkTLI126;
static object  LnkTLI125() ;
static object  (*LnkLI125)() = LnkTLI125;
static object  LnkTLI124() ;
static object  (*LnkLI124)() = LnkTLI124;
static object  LnkTLI123() ;
static object  (*LnkLI123)() = LnkTLI123;
static object  LnkTLI122() ;
static object  (*LnkLI122)() = LnkTLI122;
static object  LnkTLI121() ;
static object  (*LnkLI121)() = LnkTLI121;
static  LnkT120() ;
static  (*Lnk120)() = LnkT120;
static  LnkT119() ;
static  (*Lnk119)() = LnkT119;
static  LnkT118() ;
static  (*Lnk118)() = LnkT118;
static  LnkT117() ;
static  (*Lnk117)() = LnkT117;
static  LnkT116() ;
static  (*Lnk116)() = LnkT116;
static object  LnkTLI115() ;
static object  (*LnkLI115)() = LnkTLI115;
static  LnkT114() ;
static  (*Lnk114)() = LnkT114;
static object  LnkTLI113() ;
static object  (*LnkLI113)() = LnkTLI113;

==> gcl-2.0.tgz: gcl-2.0/cmpnew/cmpenv.h <==

static L2();
static L4();
static L7();
static L8();
static L18();
static L22();
static L24();
static object LI1();
#define VMB1
#define VMS1
#define VMV1
#define VMR1(VMT1) return(VMT1);
#define VC2
static object LI3();
#define VMB3 object  V8;
#define VMS3
#define VMV3
#define VMR3(VMT3) return(VMT3);
#define VC4
static object LI5();
#define VMB5 register object *base=vs_top; object  V24 ,V22 ,V20 ,V15 ,V14;
#define VMS5  register object *sup=vs_top+2;vs_top=sup;
#define VMV5 vs_reserve(2);
#define VMR5(VMT5) vs_top=base ; return(VMT5);
static object LI6();
#define VMB6 object  V32 ,V31;
#define VMS6
#define VMV6
#define VMR6(VMT6) return(VMT6);
#define VC7
#define VC8
static object LI9();
#define VMB9 register object *base=vs_top; object  V45 ,V44;
#define VMS9 vs_top += 1;
#define VMV9 vs_reserve(1);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI10();
#define VMB10 register object *base=vs_top;
#define VMS10  register object *sup=vs_top+2;vs_top=sup;
#define VMV10 vs_reserve(2);
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI11();
#define VMB11 register object *base=vs_top; object  V70;
#define VMS11  register object *sup=vs_top+2;vs_top=sup;
#define VMV11 vs_reserve(2);
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI12();
#define VMB12 object  V85 ,V84 ,V83;
#define VMS12
#define VMV12
#define VMR12(VMT12) return(VMT12);
static object LI13();
#define VMB13
#define VMS13
#define VMV13
#define VMR13(VMT13) return(VMT13);
static object LI14();
#define VMB14 register object *base=vs_top;
#define VMS14 vs_top += 3;
#define VMV14 vs_reserve(3);
#define VMR14(VMT14) vs_top=base ; return(VMT14);
static object LI15();
#define VMB15
#define VMS15
#define VMV15
#define VMR15(VMT15) return(VMT15);
static object LI16();
#define VMB16
#define VMS16
#define VMV16
#define VMR16(VMT16) return(VMT16);
static object LI17();
#define VMB17
#define VMS17
#define VMV17
#define VMR17(VMT17) return(VMT17);
#define VC18
static object LI19();
#define VMB19 register object *base=vs_top;
#define VMS19  register object *sup=vs_top+1;vs_top=sup;
#define VMV19 vs_reserve(1);
#define VMR19(VMT19) vs_top=base ; return(VMT19);
static object LI20();
#define VMB20 register object *base=vs_top; object  V145 ,V144;
#define VMS20  register object *sup=vs_top+5;vs_top=sup;
#define VMV20 vs_reserve(5);
#define VMR20(VMT20) vs_top=base ; return(VMT20);
static object LI21();
#define VMB21 register object *base=vs_top; object  V156;
#define VMS21 vs_top += 1;
#define VMV21 vs_reserve(1);
#define VMR21(VMT21) vs_top=base ; return(VMT21);
#define VC22 object  V185 ,V181 ,V178 ,V175;
static object LI23();
#define VMB23 register object *base=vs_top; object  V209 ,V206 ,V201 ,V200;
#define VMS23  register object *sup=vs_top+11;vs_top=sup;
#define VMV23 vs_reserve(11);
#define VMR23(VMT23) vs_top=base ; return(VMT23);
#define VC24
static object LI25();
#define VMB25 register object *base=vs_top;
#define VMS25 vs_top += 1;
#define VMV25 vs_reserve(1);
#define VMR25(VMT25) vs_top=base ; return(VMT25);
static object LI26();
#define VMB26 register object *base=vs_top; object  V299 ,V273 ,V272 ,V271 ,V270 ,V251 ,V247 ,V246;
#define VMS26  register object *sup=vs_top+5;vs_top=sup;
#define VMV26 vs_reserve(5);
#define VMR26(VMT26) vs_top=base ; return(VMT26);
#define VM26 5
#define VM25 1
#define VM24 10
#define VM23 11
#define VM22 8
#define VM21 1
#define VM20 5
#define VM19 1
#define VM18 3
#define VM17 0
#define VM16 0
#define VM15 0
#define VM14 3
#define VM13 0
#define VM12 0
#define VM11 2
#define VM10 2
#define VM9 1
#define VM8 3
#define VM7 3
#define VM6 0
#define VM5 2
#define VM4 4
#define VM3 0
#define VM2 3
#define VM1 0
static char * VVi[199]={
#define Cdata VV[198]
(char *)(LI1),
(char *)(L2),
(char *)(LI3),
(char *)(L4),
(char *)(LI5),
(char *)(LI6),
(char *)(L7),
(char *)(L8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI14),
(char *)(LI15),
(char *)(LI16),
(char *)(LI17),
(char *)(L18),
(char *)(LI19),
(char *)(LI20),
(char *)(LI21),
(char *)(L22),
(char *)(LI23),
(char *)(L24),
(char *)(LI25),
(char *)(LI26)
};
#define VV ((object *)VVi)
static  LnkT197() ;
static  (*Lnk197)() = LnkT197;
static  LnkT196() ;
static  (*Lnk196)() = LnkT196;
static  LnkT195() ;
static  (*Lnk195)() = LnkT195;
static object  LnkTLI194() ;
static object  (*LnkLI194)() = LnkTLI194;
static object  LnkTLI193() ;
static object  (*LnkLI193)() = LnkTLI193;
static object  LnkTLI192() ;
static object  (*LnkLI192)() = LnkTLI192;
static object  LnkTLI191() ;
static object  (*LnkLI191)() = LnkTLI191;
static object  LnkTLI189() ;
static object  (*LnkLI189)() = LnkTLI189;
static object  LnkTLI188() ;
static object  (*LnkLI188)() = LnkTLI188;
static  LnkT187() ;
static  (*Lnk187)() = LnkT187;
static object  LnkTLI150() ;
static object  (*LnkLI150)() = LnkTLI150;
static object  LnkTLI144() ;
static object  (*LnkLI144)() = LnkTLI144;
static  LnkT140() ;
static  (*Lnk140)() = LnkT140;
static  LnkT139() ;
static  (*Lnk139)() = LnkT139;
static  LnkT137() ;
static  (*Lnk137)() = LnkT137;
static  LnkT135() ;
static  (*Lnk135)() = LnkT135;
static object  LnkTLI134() ;
static object  (*LnkLI134)() = LnkTLI134;
static object  LnkTLI133() ;
static object  (*LnkLI133)() = LnkTLI133;
static object  LnkTLI132() ;
static object  (*LnkLI132)() = LnkTLI132;
static  LnkT131() ;
static  (*Lnk131)() = LnkT131;
static  LnkT130() ;
static  (*Lnk130)() = LnkT130;
static  LnkT129() ;
static  (*Lnk129)() = LnkT129;
static  LnkT128() ;
static  (*Lnk128)() = LnkT128;
static object  LnkTLI127() ;
static object  (*LnkLI127)() = LnkTLI127;
static object  LnkTLI126() ;
static object  (*LnkLI126)() = LnkTLI126;
static object  LnkTLI125() ;
static object  (*LnkLI125)() = LnkTLI125;
static  LnkT124() ;
static  (*Lnk124)() = LnkT124;
static  LnkT123() ;
static  (*Lnk123)() = LnkT123;
static object  LnkTLI122() ;
static object  (*LnkLI122)() = LnkTLI122;
static object  LnkTLI121() ;
static object  (*LnkLI121)() = LnkTLI121;
static  LnkT120() ;
static  (*Lnk120)() = LnkT120;
static  LnkT119() ;
static  (*Lnk119)() = LnkT119;
static  LnkT118() ;
static  (*Lnk118)() = LnkT118;
static  LnkT117() ;
static  (*Lnk117)() = LnkT117;
static  LnkT116() ;
static  (*Lnk116)() = LnkT116;
static object  LnkTLI115() ;
static object  (*LnkLI115)() = LnkTLI115;
static  LnkT114() ;
static  (*Lnk114)() = LnkT114;
static object  LnkTLI113() ;
static object  (*LnkLI113)() = LnkTLI113;
